miditk package
==============

Subpackages
-----------

.. toctree::

    miditk.common
    miditk.smf

Module contents
---------------

.. automodule:: miditk
    :members:
    :undoc-members:
    :show-inheritance:
